pub struct RangeFilter { /* private fields */ }Expand description
Range filter for matching a range of CAN IDs
Matches any message with an ID between start_id and end_id (inclusive).
Example
use canlink_hal::filter::RangeFilter;
// Match IDs 0x100-0x1FF
let filter = RangeFilter::new(0x100, 0x1FF);Implementations
Sourceimpl RangeFilter
impl RangeFilter
Sourcepub fn new_extended(start_id: u32, end_id: u32) -> Self
pub fn new_extended(start_id: u32, end_id: u32) -> Self
Sourcepub fn try_new(start_id: u32, end_id: u32) -> Result<Self, FilterError>
pub fn try_new(start_id: u32, end_id: u32) -> Result<Self, FilterError>
Try to create a new range filter, returning error if invalid
Errors
Returns FilterError::InvalidRange if start_id > end_id.
Returns FilterError::IdOutOfRange if end_id exceeds the maximum standard ID.
Sourcepub fn try_new_extended(start_id: u32, end_id: u32) -> Result<Self, FilterError>
pub fn try_new_extended(start_id: u32, end_id: u32) -> Result<Self, FilterError>
Try to create a new extended range filter, returning error if invalid
Errors
Returns FilterError::InvalidRange if start_id > end_id.
Returns FilterError::IdOutOfRange if end_id exceeds the maximum extended ID.
Sourcepub fn is_extended(&self) -> bool
pub fn is_extended(&self) -> bool
Check if this filter is for extended frames
Sourcepub fn range_size(&self) -> u32
pub fn range_size(&self) -> u32
Get the range size