Version management and compatibility checking.
This module provides types for managing backend versions and checking compatibility.
Structs
- Backend
Version - Backend version information.
Version management and compatibility checking.
This module provides types for managing backend versions and checking compatibility.